---
layout: blog
week: 178
published: 2018-09-25 16:53:07
---

Here's what happened in the [Reproducible Builds](https://reproducible-builds.org) effort between Sunday September 16 and Saturday September 22 2018:

* A reminder that the **fourth Reproducible Builds summit will take place from December 11th—13th 2018** at [Mozilla](https://wiki.mozilla.org/Paris) in Paris, France. If you are interested in attending please register by sending an email to `holger@layer-acht.org`. More details may be found on the [associated event page](https://reproducible-builds.org/events/paris2018/).

* Bernhard M. Wiedemannup updated  `disorderfs` (our [FUSE](https://github.com/libfuse/libfuse)-based filesystem that deliberately introduces non-determinism into filesystem metadata) [to use sys/xattr.h from glibc](https://salsa.debian.org/reproducible-builds/disorderfs/commit/387844f) as newer `libattr` versions have dropped their own `xattr.h` header.

* Jelle van der Waa [removed the SVN `propset` identifiers](https://lists.archlinux.org/pipermail/arch-dev-public/2018-September/029371.html) from the [Arch Linux](https://www.archlinux.org/) repository. This will make reproducing packages possible when the `PKGBUILD` is obtained from Git; previously [the `BUILDINFO` would differ](https://lists.archlinux.org/pipermail/arch-dev-public/2018-August/029355.html) due to Git lacking the aforementioned identifier.

* Daniel Shahaf started an interesting discussion on [our mailing list](https://lists.reproducible-builds.org/listinfo/rb-general) regarding [reproducing tarballs under various toolchains](https://lists.reproducible-builds.org/pipermail/rb-general/2018-September/001148.html). As a result, Daniel actually uncovered an [argument parsing bug in `libarchive`](https://github.com/libarchive/libarchive/issues/1068). Volunteers are welcome to [assist with documenting the GNU `tar` / BSD `tar` interoperability concerns](https://salsa.debian.org/reproducible-builds/reproducible-website/issues/3) that arose from this.

* An [issue was opened in the CPython bug tracker](https://bugs.python.org/issue34022) regarding test failures regarding the [`SOURCE_DATE_EPOCH`](https://reproducible-builds.org/specs/source-date-epoch/) environment variable which actually proposes to revert the previous changes.

* [Janneke](http://joyofsource.com) published a blog post entitled "[Reduced Binary Seed Bootstrap](http://joyofsource.com/reduced-binary-seed-bootstrap.html)" in which they describe how the [GuixSD](https://www.gnu.org/software/guix/) operating system is working on a small subset of packages in order to achieve a truly-auditable "[bootstrappable](http://bootstrappable.org/)" package set.

* Chris Lamb reviewed 15 Debian packages, adding to our [knowledge about identified issues](https://tests.reproducible-builds.org/debian/index_issues.html). In addition, two issue types were updated: [`fixed_timestamp_in_fonts_generated_by_ufo2ft`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/b6dc7ea0) was removed and `randomless_in_pdf2htmlex_html_output` [was renamed](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/23f31d23) to `randomness_in_pdf2htmlex_html_output`.

* [openSUSE](https://en.opensuse.org)'s wiki page [on their approach and resources regarding reproducible builds](https://en.opensuse.org/openSUSE:Reproducible_Builds) was linked on our IRC channel.

* Holger Levsen switched back to recent `i386` kernels on all `i386` build nodes and rescheduled all currently-failing [KDE](https://www.kde.org/) packages which can be seen on the [KDE package set](https://tests.reproducible-builds.org/debian/buster/i386/pkg_set_kde.html) page.

* Chris Lamb also updated the SSL certificate for [buildinfo.debian.net](https://buildinfo.debian.net/).


Patches filed
-------------

* Bernhard M. Wiedemann:

    * [libqt5-qtbase](https://build.opensuse.org/request/show/636631) (toolchain, override mtime with [`SOURCE_DATE_EPOCH`](https://reproducible-builds.org/specs/source-date-epoch/))
    * [disorderfs](https://build.opensuse.org/request/show/635881) (fix build)
    * [pitivi](https://build.opensuse.org/request/show/636099) (parallelism race)
    * [sigil](https://build.opensuse.org/request/show/637097) (fixup bad reproducibility patch)
    * [kubernetes-dashboard](https://build.opensuse.org/request/show/637008) (fix date + build from source)
    * [dateutils](https://build.opensuse.org/request/show/636875) (fix FTBFS-2018-10-07 [via upstream patch](https://github.com/hroptatyr/dateutils/pull/85))
    * [python-execnet](https://github.com/pytest-dev/execnet/pull/84) (extended fix for FTBFS-j1)
    * [yubikey-manager-qt](https://github.com/Yubico/yubikey-manager-qt/pull/58) (merged, sort `readdir(2)`)

* Chris Lamb:
    * [#909078](https://bugs.debian.org/909078) filed against [fltk1.1](https://tracker.debian.org/pkg/fltk1.1) in Debian.


diffoscope development
----------------------

diffoscope version `102` was [uploaded to Debian unstable](https://tracker.debian.org/news/989165/accepted-diffoscope-102-source-into-unstable/) by Mattia Rizzolo. It [included contributions already covered in previous weeks](https://salsa.debian.org/reproducible-builds/diffoscope/commits/102) as well as new ones from:

* Chris Lamb:
    * [Fix tests under `colord` >= 1.4.3](https://salsa.debian.org/reproducible-builds/diffoscope/commit/b1addb0). ([#908900](https://bugs.debian.org/908900))
    * [Drop `print()` statement in PPU tests](https://salsa.debian.org/reproducible-builds/diffoscope/commit/755c218).

* Marek Marczykowski-Górecki:
    * [Try fuzzy matching for non-text JSON files too](https://salsa.debian.org/reproducible-builds/diffoscope/commit/4ba7e6c). ([#909122](https://bugs.debian.org/909122))

* Mattia Rizzolo:
    * [Use the new `debhelper-compat` virtual dependency](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f23ff14).


Test framework development
--------------------------

There were a number of updates to our [Jenkins](https://jenkins.io/)-based testing framework that powers [tests.reproducible-builds.org](https://tests.reproducible-builds.org/) this week, including:

* Holger Levsen made a huge number of changes to the framework's [Arch Linux](https://www.archlinux.org/) support, including:

    * Refactoring for huge performance gains, including [a huge rework of the scheduler](https://salsa.debian.org/qa/jenkins.debian.net/commit/26377e6b), [dropping 8000 SQL queries](https://salsa.debian.org/qa/jenkins.debian.net/commit/7c77b0d3)
    * Drafting a plan on [how to switch to SQL-based HTML page generation](https://salsa.debian.org/qa/jenkins.debian.net/commit/6ed1274e).
    * A large number of bug fixes, including [removing various "Bashims"](https://salsa.debian.org/qa/jenkins.debian.net/commit/3d46a865), [preventing the scheduling of blacklisted packages](https://salsa.debian.org/qa/jenkins.debian.net/commit/4db078d4) and [ensuring notifications are not sent when they affect no packages](https://salsa.debian.org/qa/jenkins.debian.net/commit/6b98e303).
    * In addition more debug output ([1](https://salsa.debian.org/qa/jenkins.debian.net/commit/63237165), [2](https://salsa.debian.org/qa/jenkins.debian.net/commit/8acce39f), etc.) was added to catch future errors.
    * The output of rescheduled packages was changed to be sorted. ([1](https://salsa.debian.org/qa/jenkins.debian.net/commit/7e4cda0d), [2](https://salsa.debian.org/qa/jenkins.debian.net/commit/cf042521))
    * In Debian, Holger also [doubled the size of `/tmp` on the `pb3+4` nodes](https://salsa.debian.org/qa/jenkins.debian.net/commit/aa872f0f) and ensured that `rm -rf` [was called with `--one-file-system`](https://salsa.debian.org/qa/jenkins.debian.net/commit/1ef70769).

* Hans-Christoph Steiner [added the Android Tools Team packages as a "package set"](https://salsa.debian.org/qa/jenkins.debian.net/commit/fc224521).

* Lastly, Mattia Rizzolo temporarily [marked the `jtk1b-armhf-rb.debian.net` node as offline](https://salsa.debian.org/qa/jenkins.debian.net/commit/2e935533).

Misc.
-----

This week's edition was written by Bernhard M. Wiedemann, Chris Lamb, Daniel Shahaf, Holger Levsen, Jelle van der Waa, Vagrant Cascadian & reviewed by a bunch of Reproducible Builds folks on IRC & the mailing lists.
